sh: Track the uncached mapping size.

This provides a variable for tracking the uncached mapping size, and uses
it for pretty printing the uncached lowmem range. Beyond this, we'll also
be building on top of this for figuring out from where the remainder of
P2 becomes usable when constructing unrelated mappings.

Signed-off-by: Paul Mundt <lethal@linux-sh.org>
diff --git a/arch/sh/kernel/head_32.S b/arch/sh/kernel/head_32.S
index e933201..83f2b84 100644
--- a/arch/sh/kernel/head_32.S
+++ b/arch/sh/kernel/head_32.S
@@ -217,11 +217,18 @@
 	__PMB_ITER_BY_SIZE(16)
 
 	/*
 	 * Now that we can access it, update cached_to_uncached.
 	 */
 	mov.l	.Lcached_to_uncached, r0
 	mov.l	r7, @r0
 
+	mov.l	.Luncached_size, r0
+	mov	#1, r7
+	shll16	r7
+	shll8	r7
+	mov.l	r7, @r0
+
 	/*
 	 * Clear the remaining PMB entries.
 	 *
@@ -300,5 +307,6 @@
 .LFIRST_DATA_ENTRY:	.long	__MEMORY_START | PMB_V
 .LMMUCR:		.long	MMUCR
 .Lcached_to_uncached:	.long	cached_to_uncached
+.Luncached_size:	.long	uncached_size
 .LMEMORY_SIZE:		.long	__MEMORY_SIZE
 #endif
@@ -217,11 +217,18 @@
 
 	/*
-	 * Now that we can access it, update cached_to_uncached.
+	 * Now that we can access it, update cached_to_uncached and
+	 * uncached_size.
 	 */
 	mov.l	.Lcached_to_uncached, r0